# rollup-plugin-hash2 [![Travis Build Status][travis-img]][travis]

this project is fork from rollup-plugin-hash
[travis-img]: https://travis-ci.org/phamann/rollup-plugin-hash.svg
[travis]: https://travis-ci.org/phamann/rollup-plugin-hash
[rollup]: https://github.com/rollup/rollup

[Rollup] plugin to compose bundle output filenames with unique hashes, to facilitate long-term caching of your static resources.

It uses is simple placeholder pattern to substitue filename with bundle hash. I.e.
```
main.[hash].js
```
becomes:
```
main.07d2bf0d12655d9f51c0637718da4889.js
```

## Install

via npm:
```sh
npm install --save-dev rollup-plugin-hash
```

via yarn:
```sh
yarn add --dev rollup-plugin-hash
```

## Usage

```js
import { rollup } from 'rollup';
import hash from 'rollup-plugin-hash';

rollup({
    entry: 'main.js',
    plugins: [
        hash({ 
			dest: 'main.[hash].js'	
		})
    ]
});
```

or 

```js
import { rollup } from 'rollup';
import hash from 'rollup-plugin-hash';

rollup({
    entry: 'main.js',
    plugins: [
        hash({ 
			output: [
                {
                    file: 'main.js',
                    dest: 'main.[hash].js'
                }
            ]	
		})
    ]
});
```

Meanwhile, if dest filename is written the following way, only first 4 characters of hash will
be used in final filename: `main.[hash:4].js`. You could change this number to modify the
output result.

## Options

### dest

Type: `string`
Required: `true`

The template of your filename destination. Must include the placeholder `[hash]` to be replaced.

### replace

Type: `boolean`
Default: `false`
Required: `false`

Whether the hashed version should replace the main output file generated by Rollup. 
Useful in CI environments where you don't need any non-hashed assets.

### algorithm

Type: `string`
Default: `sha1`
Required: `true`

Hashing algorithm used to generate hash. Can be one of `md5`, `sha1`, `sha256`, `sha512`

### manifest

Type: `string`
Required: `false`

Filename to write a manifest to. Will generate a JSON manifest mapping input filename to hashed output filename. 
Useful if you want to dynamically generate link to your hashed output server-side.

Example manifest:
```json
{
	"main.js": "main.56770a64be1a1132502b276c4132a76bb94d9e1b.js"
}
```

### manifestKey

Type: `string`
Default: `bundle.dest`
Required: `false`

The filename used as the input key in the generated manifest map. 
Useful in certain build setups where `path.resolve` is needed as `bundle.dest` but not in the manifest.

### callback

Type: `function`
Required: `false`

Callback which is called with the resulting hashed filename. This is useful if you are integrating with other build steps and want to store the filename locally to be used in subsequent configs etc.

# License

MIT ©
